"""
Classes for skmds
"""

class Address: 
    """Class respresenting an address"""
     
    def __init__(self, dict):
        """ Constructor for Address
        :param: dict: an address as a dictionary
        """
        super().__init__()
        self.address = dict['address']
        self.city = dict['city']
        self.province = dict['prov']
        self.postal_code = dict['postal']
        
    def __str__(self):
        return f'{self.address} {self.city} {self.province} {self.postal_code}'
    
    def __repr__(self):
        return f'{self.address} {self.city} {self.province} {self.postal_code}'
    
    def __dict__(self):
        return {'address': self.address, 'city': self.city, 'province': self.province, 'postal code': self.postal_code}


class Personnel:
    """Class respresenting a person"""
    
    def __init__(self, title, lname, fname):
        """ Constructor for Personnel
        :param: title: job title
        :param: lname: last name
        :param: fname: first name
        """
        super().__init__()
        self.first_name = fname
        self.last_name = lname
        self.title = title
        
    def __str__(self):
        return f'{self.last_name}, {self.first_name}: {self.title}'
    
    def __repr__(self):
        return f'{self.first_name} {self.last_name}'
    
    def __dict__(self):
        return {'title': self.title, 'last name': self.last_name, 'first name': self.first_name}


class Municipality:
    """Class respresenting a municipality"""
    
    personnel = []
        
    def __init__(self, dict):
        """ Constructor for Municipality
        :param: dict: a muncipality as a dictionary
        """
        super().__init__()
        self.name = dict['name']
        self.category = dict['category']
        self.assessment = dict['assessment']
        self.population = dict['population']
        self.rm = dict['rm_number']
        self.phone = dict['phone']
        self.fax = dict['fax']
        self.email = dict['email']
        self.website = dict['website']
        self.mail_address = Address(dict['mail_address'])
        self.office_address = Address(dict['office_address'])
    
    def __str__(self):
        return f'{self.category} of {self.name}'
    
    def __repr__(self):
        return f'{self.category} of {self.name}'
    
    def __dict__(self):
        return {
            'name': self.name,
            'category': self.category,
            'assessment': self.assessment,
            'population': self.population,
            'rm': self.rm,
            'phone': self.phone,
            'fax': self.fax,
            'email': self.email,
            'website': self.website,
            'mail_address': self.mail_address.__dict__(),
            'office_address': self.office_address.__dict__(),
            'personnel': [pers.__dict__() for pers in self.personnel]
        }